@@ -723,6 +723,27 @@
 })();
 
 
+/// refresh-defuser.js
+// https://www.reddit.com/r/uBlockOrigin/comments/q0frv0/while_reading_a_sports_article_i_was_redirected/hf7wo9v/
+(function() {
+    const arg1 = '{{1}}';
+    const defuse = ( ) => {
+        const meta = document.querySelector('meta[http-equiv="refresh" i][content]');
+        if ( meta === null ) { return; }
+        const s = arg1 === '' || arg1 === '{{1}}'
+            ? meta.getAttribute('content')
+            : arg1;
+        const ms = Math.max(parseFloat(s) || 0, 0) * 1000;
+        setTimeout(( ) => { window.stop(); }, ms);
+    };
+    if ( document.readyState === 'loading' ) {
+        document.addEventListener('DOMContentLoaded', defuse, { once: true });
+    } else {
+        defuse();
+    }
+})();
+
+
 /// remove-attr.js
 /// alias ra.js
 (function() {
@@ -767,7 +788,7 @@
         rmattr();
         if ( /\bstay\b/.test(behavior) === false ) { return; }
         const observer = new MutationObserver(mutationHandler);
-        observer.observe(document.documentElement, {
+        observer.observe(document, {
             attributes: true,
             attributeFilter: tokens,
             childList: true,
@@ -826,7 +847,7 @@
         rmclass();
         if ( /\bstay\b/.test(behavior) === false ) { return; }
         const observer = new MutationObserver(mutationHandler);
-        observer.observe(document.documentElement, {
+        observer.observe(document, {
             attributes: true,
             attributeFilter: [ 'class' ],
             childList: true,
@@ -1513,34 +1534,37 @@
 
 /// damoh-defuser.js
 (function() {
-    var handled = new WeakSet();
-    var asyncTimer;
-    var cleanVideo = function() {
+    const handled = new WeakSet();
+    let asyncTimer;
+    const cleanVideo = function() {
         asyncTimer = undefined;
-        var v = document.querySelector('video');
+        const v = document.querySelector('video');
         if ( v === null ) { return; }
         if ( handled.has(v) ) { return; }
         handled.add(v);
         v.pause();
         v.controls = true;
-        var el = v.querySelector('meta[itemprop="contentURL"][content]');
+        let el = v.querySelector('meta[itemprop="contentURL"][content]');
         if ( el === null ) { return; }
         v.src = el.getAttribute('content');
         el = v.querySelector('meta[itemprop="thumbnailUrl"][content]');
         if ( el !== null ) { v.poster = el.getAttribute('content'); }
     };
-    var cleanVideoAsync = function() {
+    const cleanVideoAsync = function() {
         if ( asyncTimer !== undefined ) { return; }
         asyncTimer = window.requestAnimationFrame(cleanVideo);
     };
-    var observer = new MutationObserver(cleanVideoAsync);
-    observer.observe(document.documentElement, { childList: true, subtree: true });
+    const observer = new MutationObserver(cleanVideoAsync);
+    observer.observe(document, { childList: true, subtree: true });
 })();
 
 
 /// twitch-videoad.js
 // https://github.com/uBlockOrigin/uAssets/issues/5184
 // https://github.com/pixeltris/TwitchAdSolutions/commit/6be4c5313035
+// https://github.com/pixeltris/TwitchAdSolutions/commit/3d2883ea9e3a
+// https://github.com/pixeltris/TwitchAdSolutions/commit/7233b5fd2284
+// https://github.com/pixeltris/TwitchAdSolutions/commit/aad8946dab2b
 (function() {
     if ( /(^|\.)twitch\.tv$/.test(document.location.hostname) === false ) { return; }
     window.fetch = new Proxy(window.fetch, {
@@ -1552,7 +1576,8 @@
                 init instanceof Object &&
                 init.headers instanceof Object &&
                 typeof init.body === 'string' &&
-                init.body.includes('PlaybackAccessToken')
+                init.body.includes('PlaybackAccessToken') &&
+                init.body.includes('"isVod":true') === false
             ) {
                 const { headers } = init;
                 if ( typeof headers['X-Device-Id'] === 'string' ) {
@@ -1568,25 +1593,6 @@
 })();
 
 
-// https://github.com/uBlockOrigin/uAssets/issues/2912
-/// fingerprint2.js
-(function() {
-    let browserId = '';
-    for ( let i = 0; i < 8; i++ ) {
-        browserId += (Math.random() * 0x10000 + 0x1000 | 0).toString(16).slice(-4);
-    }
-    const fp2 = function(){};
-    fp2.get = function(opts, cb) {
-        if ( !cb  ) { cb = opts; }
-        setTimeout(( ) => { cb(browserId, []); }, 1);
-    };
-    fp2.prototype = {
-        get: fp2.get
-    };
-    window.Fingerprint2 = fp2;
-})();
-
-
 // https://github.com/NanoAdblocker/NanoFilters/issues/149
 /// cookie-remover.js
 (function() {
