@@ -72,6 +72,7 @@ const hiddenSettingsDefault = {
     filterOnHeaders: false,
     loggerPopupType: 'popup',
     manualUpdateAssetFetchPeriod: 500,
+    modifyWebextFlavor: 'unset',
     popupFontSize: 'unset',
     popupPanelDisabledSections: 0,
     popupPanelLockedSections: 0,
@@ -113,6 +114,24 @@ const userSettingsDefault = {
     webrtcIPAddressHidden: false,
 };
 
+const dynamicFilteringDefault = [
+    'behind-the-scene * * noop',
+    'behind-the-scene * image noop',
+    'behind-the-scene * 3p noop',
+    'behind-the-scene * inline-script noop',
+    'behind-the-scene * 1p-script noop',
+    'behind-the-scene * 3p-script noop',
+    'behind-the-scene * 3p-frame noop',
+];
+
+const hostnameSwitchesDefault = [
+    'no-large-media: behind-the-scene false',
+];
+// https://github.com/LiCybora/NanoDefenderFirefox/issues/196
+if ( vAPI.webextFlavor.soup.has('firefox') ) {
+    hostnameSwitchesDefault.push('no-csp-reports: * true');
+}
+
 const µBlock = {  // jshint ignore:line
     userSettingsDefault: userSettingsDefault,
     userSettings: Object.assign({}, userSettingsDefault),
@@ -121,6 +140,9 @@ const µBlock = {  // jshint ignore:line
     hiddenSettingsAdmin: {},
     hiddenSettings: Object.assign({}, hiddenSettingsDefault),
 
+    dynamicFilteringDefault,
+    hostnameSwitchesDefault,
+
     noDashboard: false,
 
     // Features detection.
@@ -199,6 +221,11 @@ const µBlock = {  // jshint ignore:line
     //   This can be used to defer filtering decision-making.
     readyToFilter: false,
 
+    supportStats: {
+        launchToReadiness: 0,
+        launchFromSelfie: false,
+    },
+
     pageStores: new Map(),
     pageStoresToken: 0,
 
