@@ -27,12 +27,6 @@ import punycode from '../lib/punycode.js';
 
 /******************************************************************************/
 
-{
-// >>>>> start of local scope
-
-/******************************************************************************/
-
-
 let popupFontSize = 'unset';
 vAPI.localStorage.getItemAsync('popupFontSize').then(value => {
     if ( typeof value !== 'string' || value === 'unset' ) { return; }
@@ -570,9 +564,10 @@ const renderPopup = function() {
         }
     }
 
-    const canElementPicker = popupData.canElementPicker === true && isFiltering;
-    uDom.nodeFromId('gotoPick').classList.toggle('enabled', canElementPicker);
-    uDom.nodeFromId('gotoZap').classList.toggle('enabled', canElementPicker);
+    uDom.nodeFromId('basicTools').classList.toggle(
+        'canPick',
+        popupData.canElementPicker === true && isFiltering
+    );
 
     let blocked, total;
     if ( popupData.pageCounts !== undefined ) {
@@ -844,6 +839,17 @@ const gotoPick = function() {
 
 /******************************************************************************/
 
+const gotoReport = function() {
+    messaging.send('popupPanel', {
+        what: 'launchReporter',
+        tabId: popupData.tabId,
+    });
+
+    vAPI.closePopup();
+};
+
+/******************************************************************************/
+
 const gotoURL = function(ev) {
     if ( this.hasAttribute('href') === false ) { return; }
 
@@ -1382,6 +1388,7 @@ const getPopupData = async function(tabId, first = false) {
 uDom('#switch').on('click', toggleNetFilteringSwitch);
 uDom('#gotoZap').on('click', gotoZap);
 uDom('#gotoPick').on('click', gotoPick);
+uDom('#gotoReport').on('click', gotoReport);
 uDom('.hnSwitch').on('click', ev => { toggleHostnameSwitch(ev); });
 uDom('#saveRules').on('click', saveFirewallRules);
 uDom('#revertRules').on('click', ( ) => { revertFirewallRules(); });
@@ -1402,6 +1409,3 @@ document.querySelector('#firewall > [data-type="3p-frame"] .filter')
     });
 
 /******************************************************************************/
-
-// <<<<< end of local scope
-}
